Crate tokio_uds_proto

Crate tokio_uds_proto 

This crate provides a drop in replacement for the TcpClient and TcpServer from tokio-proto that operates over Unix domain sockets instead of a TCP connection. This crate is missing the threads() method from TcpServer since Unix domain sockets do not support SO_REUSEADDR.

Structs

UnixClient
Builds client connections to external services.
UnixServer
A builder for Unix Socket servers.